/*
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package benten.cat.glossary.ui.views.messages;

import java.math.BigDecimal;
import java.text.MessageFormat;
import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * 用語集ビューのためのメッセージ。
 *
 * リソースバンドル定義: [GlossaryViewMessages]。<BR>
 * このクラスはリソースバンドル定義書から自動生成されたリソースバンドルクラスです。<BR>
 * 既知のロケール<BR>
 * <UL>
 * <LI>en
 * <LI>ja
 * </UL>
 */
public class GlossaryViewMessages {
    /**
     * リソースバンドルオブジェクト。
     *
     * 内部的に実際に入力を行うリソースバンドルを記憶します。
     */
    private ResourceBundle fResourceBundle;

    /**
     * GlossaryViewMessagesクラスのコンストラクタ。
     *
     * 基底名[GlossaryViewMessages]、デフォルトのロケール、呼び出し側のクラスローダを使用して、リソースバンドルを取得します。
     */
    public GlossaryViewMessages() {
        try {
            fResourceBundle = ResourceBundle.getBundle("benten/cat/glossary/ui/views/messages/GlossaryViewMessages");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * GlossaryViewMessagesクラスのコンストラクタ。
     *
     * 基底名[GlossaryViewMessages]、指定されたロケール、呼び出し側のクラスローダを使用して、リソースバンドルを取得します。
     *
     * @param locale ロケールの指定
     */
    public GlossaryViewMessages(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("benten/cat/glossary/ui/views/messages/GlossaryViewMessages", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * GlossaryViewMessagesクラスのコンストラクタ。
     *
     * 基底名[GlossaryViewMessages]、指定されたロケール、指定されたクラスローダを使用して、リソースバンドルを取得します。
     *
     * @param locale ロケールの指定
     * @param loader クラスローダの指定
     */
    public GlossaryViewMessages(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("benten/cat/glossary/ui/views/messages/GlossaryViewMessages", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * 内部的に保持しているリソースバンドルオブジェクトを取得します。
     *
     * @return 内部的に保持しているリソースバンドルオブジェクト。
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[GlossaryViewMessages], key[Source]
     *
     * [Source] (en)<br>
     * [ソース] (ja)<br>
     *
     * @return key[Source]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getSource() {
        // 初期値として定義書の値を利用します。
        String strFormat = "Source";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("Source");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[GlossaryViewMessages], key[Target]
     *
     * [Target] (en)<br>
     * [ターゲット] (ja)<br>
     *
     * @return key[Target]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getTarget() {
        // 初期値として定義書の値を利用します。
        String strFormat = "Target";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("Target");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[GlossaryViewMessages], key[Note]
     *
     * [Notes] (en)<br>
     * [ノート] (ja)<br>
     *
     * @return key[Note]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getNote() {
        // 初期値として定義書の値を利用します。
        String strFormat = "Notes";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("Note");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[GlossaryViewMessages], key[ReloadGlossary]
     *
     * [Reload Glossary] (en)<br>
     * [用語集のリロード] (ja)<br>
     *
     * @return key[ReloadGlossary]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getReloadGlossary() {
        // 初期値として定義書の値を利用します。
        String strFormat = "Reload Glossary";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("ReloadGlossary");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[GlossaryViewMessages], key[ReloadGlossaryToolTipText]
     *
     * [Reload Glossary] (en)<br>
     * [用語集のリロード] (ja)<br>
     *
     * @return key[ReloadGlossaryToolTipText]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getReloadGlossaryToolTipText() {
        // 初期値として定義書の値を利用します。
        String strFormat = "Reload Glossary";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("ReloadGlossaryToolTipText");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[GlossaryViewMessages], key[CopySource]
     *
     * [Copy Source] (en)<br>
     * [ソースのコピー] (ja)<br>
     *
     * @return key[CopySource]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCopySource() {
        // 初期値として定義書の値を利用します。
        String strFormat = "Copy Source";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CopySource");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[GlossaryViewMessages], key[CopyTarget]
     *
     * [Copy Target] (en)<br>
     * [ターゲットのコピー] (ja)<br>
     *
     * @return key[CopyTarget]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getCopyTarget() {
        // 初期値として定義書の値を利用します。
        String strFormat = "Copy Target";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CopyTarget");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[GlossaryViewMessages], key[Msg.001]
     *
     * [{0,number} terms found.] (en)<br>
     * [{0,number} 件の用語がみつかりました。] (ja)<br>
     *
     * @param arg0 置換文字列{0}を置換する値。java.math.BigDecimal型を与えてください。
     * @return key[Msg.001]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getMsg001(final BigDecimal arg0) {
        // 初期値として定義書の値を利用します。
        String strFormat = "{0,number} terms found.";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("Msg.001");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // 与えられた引数を元に置換文字列を置き換えます。
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }

    /**
     * bundle[GlossaryViewMessages], key[Msg.002]
     *
     * [Term No. {0,number}] (en)<br>
     * [{0,number} 件目] (ja)<br>
     *
     * @param arg0 置換文字列{0}を置換する値。java.math.BigDecimal型を与えてください。
     * @return key[Msg.002]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getMsg002(final BigDecimal arg0) {
        // 初期値として定義書の値を利用します。
        String strFormat = "Term No. {0,number}";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("Msg.002");
            }
        } catch (MissingResourceException ex) {
        }
        final MessageFormat messageFormat = new MessageFormat(strFormat);
        final StringBuffer strbuf = new StringBuffer();
        // 与えられた引数を元に置換文字列を置き換えます。
        messageFormat.format(new Object[] {arg0}, strbuf, null);
        return strbuf.toString();
    }
}
