/*
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package benten.cat.tm.ui.actions.messages;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * 翻訳メモリー検索結果を表示するビューのためのメッセージ。
 *
 * リソースバンドル定義: [ShowTranslationActionMessages]。<BR>
 * このクラスはリソースバンドル定義書から自動生成されたリソースバンドルクラスです。<BR>
 * 既知のロケール<BR>
 * <UL>
 * <LI>en
 * <LI>ja
 * </UL>
 */
public class ShowTranslationActionMessages {
    /**
     * リソースバンドルオブジェクト。
     *
     * 内部的に実際に入力を行うリソースバンドルを記憶します。
     */
    private ResourceBundle fResourceBundle;

    /**
     * ShowTranslationActionMessagesクラスのコンストラクタ。
     *
     * 基底名[ShowTranslationActionMessages]、デフォルトのロケール、呼び出し側のクラスローダを使用して、リソースバンドルを取得します。
     */
    public ShowTranslationActionMessages() {
        try {
            fResourceBundle = ResourceBundle.getBundle("benten/cat/tm/ui/actions/messages/ShowTranslationActionMessages");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * ShowTranslationActionMessagesクラスのコンストラクタ。
     *
     * 基底名[ShowTranslationActionMessages]、指定されたロケール、呼び出し側のクラスローダを使用して、リソースバンドルを取得します。
     *
     * @param locale ロケールの指定
     */
    public ShowTranslationActionMessages(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("benten/cat/tm/ui/actions/messages/ShowTranslationActionMessages", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * ShowTranslationActionMessagesクラスのコンストラクタ。
     *
     * 基底名[ShowTranslationActionMessages]、指定されたロケール、指定されたクラスローダを使用して、リソースバンドルを取得します。
     *
     * @param locale ロケールの指定
     * @param loader クラスローダの指定
     */
    public ShowTranslationActionMessages(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("benten/cat/tm/ui/actions/messages/ShowTranslationActionMessages", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * 内部的に保持しているリソースバンドルオブジェクトを取得します。
     *
     * @return 内部的に保持しているリソースバンドルオブジェクト。
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[ShowTranslationActionMessages], key[JobName]
     *
     * [Searching the TM...] (en)<br>
     * [TM 検索中...] (ja)<br>
     *
     * @return key[JobName]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getJobName() {
        // 初期値として定義書の値を利用します。
        String strFormat = "Searching the TM...";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("JobName");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }

    /**
     * bundle[ShowTranslationActionMessages], key[Msg.001]
     *
     * [Failed to get the TM engine] (en)<br>
     * [TM エンジンの取得に失敗] (ja)<br>
     *
     * @return key[Msg.001]に対応する値。外部から読み込みができない場合には、定義書の値を戻します。必ずnull以外の値が戻ります。
     */
    public String getMsg001() {
        // 初期値として定義書の値を利用します。
        String strFormat = "Failed to get the TM engine";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("Msg.001");
            }
        } catch (MissingResourceException ex) {
        }
        // 置換文字列はひとつもありません。
        return strFormat;
    }
}
