/*******************************************************************************
 * Copyright (c) 2010 IGA Tosiki.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
/*
 * Copyright (C) 2010 IGA Tosiki.
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package benten.twa.filter.engine.po;

import java.io.BufferedWriter;
import java.io.IOException;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.util.List;

import blanco.commons.util.BlancoStringUtil;

/**
 * PO ファイルを単に書き込むだけのクラスです。文字列リテラルのエスケープ処理すら行ないません。
 * 
 * @author Tosiki Iga
 * @see "http://www.gnu.org/software/hello/manual/gettext/PO-Files.html"
 */
public class SimplePOWriter {
	/**
	 * 処理のエントリポイント。
	 * @param entryList 出力したいエントリのリスト。
	 * @param outStream 出力ストリーム。
	 * @throws IOException 入出力例外が発生した場合。
	 */
	void process(final List<SimplePOEntry> entryList, final OutputStream outStream) throws IOException {
		final BufferedWriter writer = new BufferedWriter(new OutputStreamWriter(outStream, "UTF-8")); //$NON-NLS-1$
		for (int index = 0; index < entryList.size(); index++) {
			final SimplePOEntry entry = entryList.get(index);
			for (String comment : entry.getCommentList()) {
				writer.write("#" + BlancoStringUtil.null2Blank(comment)); //$NON-NLS-1$
				writer.write("\n"); //$NON-NLS-1$
			}

			if ("x-benten-whitespace".equals(BlancoStringUtil.null2Blank(entry.getCommand()))) { //$NON-NLS-1$
				if (index == entryList.size() - 1) {
					// 最終行の場合、強制的な改行付与は抑止しています。
				} else {
					// TODO このような強制的な改行付与は、本来望ましくありません。
					// TODO もとのホワイトスペースを記憶して再現するように改良してください。
					writer.write('\n');
				}
			} else {
				writer.write(BlancoStringUtil.null2Blank(entry.getCommand()));
			}

			boolean isFirstLiteral = true;
			for (String literal : entry.getStringLiteralList()) {
				if (isFirstLiteral) {
					isFirstLiteral = false;
					writer.write(" "); //$NON-NLS-1$
				}
				writer.write("\"" + BlancoStringUtil.null2Blank(literal) + "\""); //$NON-NLS-1$ //$NON-NLS-2$
				writer.write("\n"); //$NON-NLS-1$
			}
		}
		writer.close();
	}
}
