/*
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package benten.twa.xliff.core.valueobject;

/**
 * 処理クラス [BentenMergeXliffProcess]の入力バリューオブジェクトクラスです。
 */
public class BentenMergeXliffProcessInput {
    /**
     * verboseモードで動作させるかどうか。
     *
     * フィールド: [verbose]。
     * デフォルト: [false]。
     */
    private boolean fVerbose = false;

    /**
     * マージ元となる XLIFF を格納するディレクトリ。
     *
     * フィールド: [sourcedir]。
     */
    private String fSourcedir;

    /**
     * マージ先となる XLIFF を格納するディレクトリ。
     *
     * フィールド: [targetdir]。
     */
    private String fTargetdir;

    /**
     * フィールド [verbose] の値を設定します。
     *
     * フィールドの説明: [verboseモードで動作させるかどうか。]。
     *
     * @param argVerbose フィールド[verbose]に設定する値。
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * フィールド [verbose] の値を取得します。
     *
     * フィールドの説明: [verboseモードで動作させるかどうか。]。
     * デフォルト: [false]。
     *
     * @return フィールド[verbose]から取得した値。
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * フィールド [sourcedir] の値を設定します。
     *
     * フィールドの説明: [マージ元となる XLIFF を格納するディレクトリ。]。
     *
     * @param argSourcedir フィールド[sourcedir]に設定する値。
     */
    public void setSourcedir(final String argSourcedir) {
        fSourcedir = argSourcedir;
    }

    /**
     * フィールド [sourcedir] の値を取得します。
     *
     * フィールドの説明: [マージ元となる XLIFF を格納するディレクトリ。]。
     *
     * @return フィールド[sourcedir]から取得した値。
     */
    public String getSourcedir() {
        return fSourcedir;
    }

    /**
     * フィールド [targetdir] の値を設定します。
     *
     * フィールドの説明: [マージ先となる XLIFF を格納するディレクトリ。]。
     *
     * @param argTargetdir フィールド[targetdir]に設定する値。
     */
    public void setTargetdir(final String argTargetdir) {
        fTargetdir = argTargetdir;
    }

    /**
     * フィールド [targetdir] の値を取得します。
     *
     * フィールドの説明: [マージ先となる XLIFF を格納するディレクトリ。]。
     *
     * @return フィールド[targetdir]から取得した値。
     */
    public String getTargetdir() {
        return fTargetdir;
    }

    /**
     * このバリューオブジェクトの文字列表現を取得します。
     *
     * <P>使用上の注意</P>
     * <UL>
     * <LI>オブジェクトのシャロー範囲のみ文字列化の処理対象となります。
     * <LI>オブジェクトが循環参照している場合には、このメソッドは使わないでください。
     * </UL>
     *
     * @return バリューオブジェクトの文字列表現。
     */
    @Override
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("benten.twa.xliff.core.valueobject.BentenMergeXliffProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",sourcedir=" + fSourcedir);
        buf.append(",targetdir=" + fTargetdir);
        buf.append("]");
        return buf.toString();
    }
}
