/*******************************************************************************
 * Copyright (c) 2009 Information-technology Promotion Agency, Japan.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *******************************************************************************/
package benten.ui.dialogs;

import junit.framework.TestCase;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IWorkspaceRoot;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.Path;

import benten.ui.UiPlugin;

public class ResourceFileSelectionDialogTest extends TestCase {

	private IProject createProject() throws CoreException {
		final IWorkspaceRoot root = ResourcesPlugin.getWorkspace().getRoot();
		final IProject project = root.getProject("test.project");
		if (!project.exists()) {
			project.create(null);
		}
		return project;
	}

	public void testAcceptSelection() throws CoreException {
		final IProject project = createProject();

		final ResourceFileSelectionDialog dialog = new ResourceFileSelectionDialog(UiPlugin.getShell());
		assertTrue(dialog.acceptSelection(project.getFile(new Path("test.file"))));
		assertTrue(dialog.acceptSelection(project.getFile(new Path("test.txt"))));
		assertFalse(dialog.acceptSelection(project.getFolder(new Path("test.folder"))));

		dialog.setExtensions(".txt");
		assertFalse(dialog.acceptSelection(project.getFile(new Path("test.file"))));
		assertTrue(dialog.acceptSelection(project.getFile(new Path("test.txt"))));
		assertFalse(dialog.acceptSelection(project.getFolder(new Path("test.folder"))));

		dialog.setExtensions(".file", ".txt", ".folder");
		assertTrue(dialog.acceptSelection(project.getFile(new Path("test.file"))));
		assertTrue(dialog.acceptSelection(project.getFile(new Path("test.txt"))));
		assertFalse(dialog.acceptSelection(project.getFolder(new Path("test.folder"))));
	}
}
